<?php
/*
Plugin Name: LINEシェアボタン
Description: このページをLINEで紹介するボタンを表示するショートコードを提供します。
Version: 2.0
Author: sakamoto
*/

function lsb_enqueue_styles() {
    $options = get_option('lsb_settings');
    $font_family = $options['font_family'] ?? '';
    $google_fonts = [
        'Noto Sans JP' => 'Noto+Sans+JP',
        'M PLUS Rounded 1c' => 'M+PLUS+Rounded+1c',
        'Noto Serif JP' => 'Noto+Serif+JP',
        'Kosugi Maru' => 'Kosugi+Maru',
        'Kosugi' => 'Kosugi',
        'Yuji Syuku' => 'Yuji+Syuku',
        'Yusei Magic' => 'Yusei+Magic'
    ];
    if (array_key_exists($font_family, $google_fonts)) {
        wp_enqueue_style('google-font', 'https://fonts.googleapis.com/css2?family=' . $google_fonts[$font_family] . '&display=swap');
    }
    wp_enqueue_style('lsb-style', plugin_dir_url(__FILE__) . 'style.css');
}
add_action('wp_enqueue_scripts', 'lsb_enqueue_styles');

function lsb_line_share_button() {
    $url = urlencode(get_permalink());
    $options = get_option('lsb_settings');

    $button_text = $options['button_text'] ?? 'このページをLINEで紹介する';
    $bg_color = $options['bg_color'] ?? '#00c300';
    $text_color = $options['text_color'] ?? '#ffffff';
    $font_family = $options['font_family'] ?? 'inherit';

    $font_size_pc = $options['font_size_pc'] ?? '16px';
    $font_size_tab = $options['font_size_tab'] ?? '16px';
    $font_size_sp = $options['font_size_sp'] ?? '16px';

    $padding_top = $options['padding_top'] ?? '10px';
    $padding_bottom = $options['padding_bottom'] ?? '10px';
    $padding_left = $options['padding_left'] ?? '20px';
    $padding_right = $options['padding_right'] ?? '20px';

    $margin_top = $options['margin_top'] ?? '10px';
    $margin_bottom = $options['margin_bottom'] ?? '10px';
    $margin_left = $options['margin_left'] ?? '0px';
    $margin_right = $options['margin_right'] ?? '0px';

    $text_align = $options['text_align'] ?? 'center';


return "<style>
    @media (max-width: 767px) {
        .custom-button { font-size: {$font_size_sp} !important; }
    }
    @media (min-width: 768px) and (max-width: 1024px) {
        .custom-button { font-size: {$font_size_tab} !important; }
    }
    @media (min-width: 1025px) {
        .custom-button { font-size: {$font_size_pc} !important; }
    }
    </style>
    <div style='display: flex; justify-content: {$text_align}; margin: {$margin_top} {$margin_right} {$margin_bottom} {$margin_left}; width: 100%;'>
        <a href='https://social-plugins.line.me/lineit/share?url={$url}' target='_blank' class='custom-button' style='background-color: {$bg_color}; color: {$text_color}; padding: {$padding_top} {$padding_right} {$padding_bottom} {$padding_left}; border-radius: 8px; text-decoration: none; display: inline-block; font-family: {$font_family}, sans-serif; z-index:9999;'>
            {$button_text}
        </a>
    </div>";
}
add_shortcode('line_share_button', 'lsb_line_share_button');

function lsb_add_settings_menu() {
    add_options_page('シェアボタン設定', 'シェアボタン', 'manage_options', 'lsb-settings', 'lsb_render_settings_page');
}
add_action('admin_menu', 'lsb_add_settings_menu');

function lsb_register_settings() {
    register_setting('lsb_settings_group', 'lsb_settings');
}
add_action('admin_init', 'lsb_register_settings');

function lsb_render_settings_page() {
    include plugin_dir_path(__FILE__) . 'settings-page.php';
}

function lsb_admin_styles($hook) {
    if ($hook === 'settings_page_lsb-settings') {
        wp_enqueue_style('lsb-admin-style', plugin_dir_url(__FILE__) . 'admin-style.css');
    }
}
add_action('admin_enqueue_scripts', 'lsb_admin_styles');

?>
